@@ -29,35 +29,43 @@ class DocumentModel : public QAbstractListModel
     Q_PROPERTY(int activePageRotation READ activePageRotation NOTIFY activePageChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
     Q_PROPERTY(bool isReady READ isReady NOTIFY isReadyChanged)
-    
+
 public:
-    enum DocumentModelRoles { ImageUrlRole = Qt::UserRole + 1,
+    enum DocumentModelRoles {
+        ImageUrlRole = Qt::UserRole + 1,
         RotationAngleRole,
         AspectRatioRole,
         PreviewWidthRole,
         PreviewHeightRole,
-        IsSavedRole};
+        IsSavedRole
+    };
 
-    enum RotateOption { Rotate90positive,
+    enum RotateOption {
+        Rotate90positive,
         Rotate90negative,
-        Flip180};
+        Flip180
+    };
 
     Q_ENUM(RotateOption)
 
-    enum FlipPagesOption { FlipEven,
+    enum FlipPagesOption {
+        FlipEven,
         FlipOdd,
-        FlipAll};
+        FlipAll
+    };
 
     Q_ENUM(FlipPagesOption)
 
-    enum ReorderOption { ReorderDuplex,
+    enum ReorderOption {
+        ReorderDuplex,
         ReorderDuplexReversed,
-        Reverse};
+        Reverse
+    };
 
     Q_ENUM(ReorderOption)
 
     explicit DocumentModel(QObject *parent = nullptr);
-    ~DocumentModel();
+    ~DocumentModel() override;
 
     QString name() const;
     QString fileName() const;
@@ -102,7 +110,10 @@ Q_SIGNALS:
     void countChanged();
     void isReadyChanged(const bool isReady);
     void newPageAdded();
-    void saveDocument(const QUrl &fileUrl, const SkanpageUtils::DocumentPages &document, const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument, const QString &title = QString());
+    void saveDocument(const QUrl &fileUrl,
+                      const SkanpageUtils::DocumentPages &document,
+                      const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument,
+                      const QString &title = QString());
     void saveNewPageTemporary(const int pageID, const QImage &image);
     void sharingDocumentsCreated(const QVariantList &fileUrls);
 
