@@ -8,25 +8,25 @@
 #ifndef SKANPAGE_H
 #define SKANPAGE_H
 
+#include <QImage>
 #include <QObject>
 #include <QString>
-#include <QImage>
 
 #include <KActionCollection>
 
-#include <KSaneCore/Interface>
 #include <KSaneCore/DeviceInformation>
+#include <KSaneCore/Interface>
 
 #include <memory>
 
+#include "DevicesModel.h"
+#include "DocumentModel.h"
+#include "FilteredOptionsModel.h"
+#include "FormatModel.h"
+#include "OCRLanguageModel.h"
 #include "SkanpageUtils.h"
 #include "skanpage_config.h"
 #include "skanpage_state.h"
-#include "DocumentModel.h"
-#include "OCRLanguageModel.h"
-#include "FilteredOptionsModel.h"
-#include "FormatModel.h"
-#include "DevicesModel.h"
 
 class SkanpagePrivate;
 
@@ -56,7 +56,6 @@ class Skanpage : public QObject
     Q_PROPERTY(bool previewImageAvailable READ previewImageAvailable NOTIFY previewImageChanged)
 
 public:
-
     enum ApplicationState {
         ScanInProgress,
         ReadyForScan,
@@ -74,7 +73,7 @@ public:
     Q_ENUM(ScanSplit)
 
     explicit Skanpage(const QString &deviceName, const QUrl &dumpOptionsUrl, QObject *parent = nullptr);
-    ~Skanpage();
+    ~Skanpage() override;
 
     QString deviceVendor() const;
     QString deviceModel() const;
@@ -108,7 +107,7 @@ public:
     Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());
     Q_INVOKABLE bool OCRavailable() const;
     Q_INVOKABLE void print();
-    Q_INVOKABLE void registerAction(QObject* item, QObject* shortcuts, const QString &iconText);
+    Q_INVOKABLE void registerAction(QObject *item, QObject *shortcuts, const QString &iconText);
     Q_INVOKABLE void showShortcutsDialog();
     Q_INVOKABLE void clearSubAreas();
     Q_INVOKABLE void eraseSubArea(int index);
